@@ -57,7 +57,7 @@ C***********************************************************************
 C***********************************************************************
 C
 C***********************************************************************
-      subroutine bckslf(m,nsubmax,nsuper,nrhs,lindx,xlindx,nnzlmax,lnz,
+      subroutine pivotforwardsolve(m,nsuper,nrhs,lindx,xlindx,lnz,
      &                   xlnz,invp,perm,xsuper,newrhs,sol,b)
 c Sparse least squares solver via Ng-Peyton's sparse Cholesky 
 c    factorization for sparse symmetric positive definite
@@ -68,8 +68,6 @@ c     lindx -- an nsub-vector of interger which contains, in
 c           column major oder, the row subscripts of the nonzero
 c           entries in L in a compressed storage format
 c     xlindx -- an nsuper-vector of integer of pointers for lindx
-c     nnzlmax -- the upper bound of the non-zero entries in
-c                L stored in lnz, including the diagonal entries
 c     lnz -- First contains the non-zero entries of d; later
 c            contains the entries of the Cholesky factor
 c     xlnz -- column pointer for L stored in lnz
@@ -88,13 +86,13 @@ c     y -- an m-vector of least squares solution
 c WORK ARRAYS:
 c     b -- an m-vector, usually the rhs of the equality constraint
 c          X'a = (1-tau)X'e in the rq setting
-c        1         2         3         4         5         6         7
-c23456789012345678901234567890123456789012345678901234567890123456789012
-      integer nnzlmax,nsubmax,nsuper,nrhs,lindx(nsubmax),xlindx(m+1),
-     &        invp(m),perm(m),xlnz(m+1),
-     &        xsuper(m+1)
-      double precision lnz(nnzlmax),b(m,nrhs),newrhs(m),sol(m,nrhs)
-c Call blkslv: Numerical solution
+      implicit none
+
+      integer m,nsuper,nrhs,lindx(*),xlindx(m+1),
+     &        invp(m),perm(m),xlnz(m+1), xsuper(m+1)
+      integer i,j
+      double precision lnz(*),b(m,nrhs),newrhs(m),sol(m,nrhs)
+
       do j = 1,nrhs
          do i = 1,m
             newrhs(i) = b(perm(i),j)
@@ -107,42 +105,15 @@ c Call blkslv: Numerical solution
       return
       end
 C***********************************************************************
-      subroutine bckslb(m,nsubmax,nsuper,nrhs,lindx,xlindx,nnzlmax,lnz,
+      subroutine pivotbacksolve(m,nsuper,nrhs,lindx,xlindx,lnz,
      &                   xlnz,invp,perm,xsuper,newrhs,sol,b)
-c Sparse least squares solver via Ng-Peyton's sparse Cholesky 
-c    factorization for sparse symmetric positive definite
-c INPUT:
-c     m -- the number of column in the design matrix X
-c     nsubmax -- upper bound of the dimension of lindx
-c     lindx -- an nsub-vector of interger which contains, in 
-c           column major oder, the row subscripts of the nonzero
-c           entries in L in a compressed storage format
-c     xlindx -- an nsuper-vector of integer of pointers for lindx
-c     nnzlmax -- the upper bound of the non-zero entries in
-c                L stored in lnz, including the diagonal entries
-c     lnz -- First contains the non-zero entries of d; later
-c            contains the entries of the Cholesky factor
-c     xlnz -- column pointer for L stored in lnz
-c     invp -- an m-vector of integer of inverse permutation
-c             vector
-c     perm -- an m-vector of integer of permutation vector
-c     xsuper -- array of length m+1 containing the supernode
-c               partitioning
-c     newrhs -- extra work vector for right-hand side and
-c               solution
-c     sol -- the least squares solution
-c     b -- an m-vector, usualy the rhs of the equality constraint
-c          X'a = (1-tau)X'e in the rq setting
-c OUTPUT:
-c     y -- an m-vector of least squares solution
-c WORK ARRAYS:
-c     b -- an m-vector, usually the rhs of the equality constraint
-c          X'a = (1-tau)X'e in the rq setting
-      integer nnzlmax,nsubmax,nsuper,nrhs,lindx(nsubmax),xlindx(m+1),
-     &        invp(m),perm(m),xlnz(m+1),
-     &        xsuper(m+1)
-      double precision lnz(nnzlmax),b(m,nrhs),newrhs(m),sol(m,nrhs)
-c Call blkslv: Numerical solution
+c     see above
+      implicit none
+
+      integer m, nsuper,nrhs,lindx(*),xlindx(m+1),
+     &        invp(m),perm(m),xlnz(m+1), xsuper(m+1)
+      double precision lnz(*),b(m,nrhs),newrhs(m),sol(m,nrhs)
+      integer i,j
       do j = 1,nrhs
          do i = 1,m
             newrhs(i) = b(perm(i),j)
@@ -155,7 +126,7 @@ c Call blkslv: Numerical solution
       return
       end
 C***********************************************************************
-      subroutine bckslv(m,nsubmax,nsuper,nrhs,lindx,xlindx,nnzlmax,lnz,
+      subroutine backsolves(m,nsuper,nrhs,lindx,xlindx,lnz,
      &                   xlnz,invp,perm,xsuper,newrhs,sol,b)
 c Sparse least squares solver via Ng-Peyton's sparse Cholesky 
 c    factorization for sparse symmetric positive definite
@@ -186,12 +157,13 @@ c     y -- an m-vector of least squares solution
 c WORK ARRAYS:
 c     b -- an m-vector, usually the rhs of the equality constraint
 c          X'a = (1-tau)X'e in the rq setting
-      integer nnzlmax,nsubmax,nsuper,nrhs,lindx(nsubmax),xlindx(m+1),
-     &        invp(m),perm(m),xlnz(m+1),
-     &        xsuper(m+1)
-      double precision lnz(nnzlmax),b(m,nrhs),newrhs(m),sol(m,nrhs)
+      implicit none
 
-c Call blkslv: Numerical solution
+      integer m,nsuper,nrhs,lindx(*),xlindx(m+1),
+     &        invp(m),perm(m),xlnz(m+1), xsuper(m+1)
+      double precision lnz(*),b(m,nrhs),newrhs(m),sol(m,nrhs)
+
+      integer i,j
       do j = 1,nrhs
          do i = 1,m
             newrhs(i) = b(perm(i),j)
